@@ -53,7 +53,7 @@ $lang = array_merge($lang, array(
 	'SYSTEM_TIMEZONE'				=> 'Часовой пояс для гостей',
 	'SYSTEM_TIMEZONE_EXPLAIN'		=> 'Часовой пояс, используемый для отображения времени у незарегистрированных пользователей (гости, боты). Зарегистрированные пользователи настраивают свой часовой пояс при регистрации и могут изменить его в Личном разделе.',
 	'WARNINGS_EXPIRE'				=> 'Длительность предупреждений',
-	'WARNINGS_EXPIRE_EXPLAIN'		=> 'Количество дней, по истечении которых выданное пользователю предупреждение будет автоматически снято с него и удалено из его записей.',
+	'WARNINGS_EXPIRE_EXPLAIN'		=> 'Количество дней, по истечении которых выданное пользователю предупреждение будет автоматически снято. Установите 0, чтобы сделать предупреждения бессрочными.',
 ));
 
 // Board Features
@@ -174,7 +174,7 @@ $lang = array_merge($lang, array(
 	'MAX_POST_URLS'					=> 'Максимальное количество ссылок в сообщении',
 	'MAX_POST_URLS_EXPLAIN'			=> 'Максимальное количество ссылок в сообщении. Введите 0 для снятия ограничений.',
 	'MIN_CHAR_LIMIT'				=> 'Минимальное количество символов в сообщениях',
-	'MIN_CHAR_LIMIT_EXPLAIN'		=> 'Минимальное количество символов, необходимое для публикации сообщений и личных сообщений.',
+	'MIN_CHAR_LIMIT_EXPLAIN'		=> 'Минимальное количество символов, необходимое для публикации сообщений и личных сообщений. Наименьшее возможное значение равно 1.',
 	'POSTING'						=> 'Размещение сообщений',
 	'POSTS_PER_PAGE'				=> 'Сообщений на странице',
 	'QUOTE_DEPTH_LIMIT'				=> 'Максимальная глубина вложенности цитат',
