@@ -43,7 +43,7 @@ $lang = array_merge($lang, array(
 	'TRANSLATION_INFO'	=> '<a href=\'http://www.phpbbguru.net/\'>Русская поддержка phpBB</a>',
 	'DIRECTION'			=> 'ltr',
 	'DATE_FORMAT'		=> '|d.m.Y|',	// 01 Jan 2007 (with Relative days enabled)
-	'USER_LANG'			=> 'ru-ru',
+	'USER_LANG'			=> 'ru',
 
 	'1_DAY'			=> '1 день',
 	'1_MONTH'		=> '1 месяц',
@@ -165,6 +165,7 @@ $lang = array_merge($lang, array(
 	'EMPTY_MESSAGE_SUBJECT'				=> 'Вы должны указать тему нового сообщения.',
 	'ENABLED'							=> 'Включено',
 	'ENCLOSURE'							=> 'Ограничитель',
+	'ENTER_USERNAME'					=> 'Введите имя пользователя',
 	'ERR_CHANGING_DIRECTORY'			=> 'Не удалось сменить папку.',
 	'ERR_CONNECTING_SERVER'				=> 'Ошибка подключения к серверу.',
 	'ERR_JAB_AUTH'						=> 'Не удалось авторизоваться на сервере Jabber.',
@@ -200,6 +201,7 @@ $lang = array_merge($lang, array(
 	'FORUM_RULES_LINK'		=> 'Посмотреть правила форума',
 	'FROM'					=> 'из',
 	'FSOCK_DISABLED'		=> 'Действие не может быть завершено, поскольку функция <var>fsockopen</var> отключена или запрашиваемый сервер не найден.',
+	'FSOCK_TIMEOUT'			=> 'Таймаут соединения.',
 
 	'FTP_FSOCK_HOST'				=> 'FTP-сервер',
 	'FTP_FSOCK_HOST_EXPLAIN'		=> 'FTP-сервер для соединения с сайтом.',
@@ -651,6 +653,10 @@ $lang = array_merge($lang, array(
 	'UNREAD_PMS'			=> 'Непрочитанных сообщений: <strong>%d</strong>',
 	'UNREAD_POST'			=> 'Непрочитанное сообщение',
 	'UNREAD_POSTS'			=> 'Непрочитанные сообщения',
+	'UNWATCH_FORUM_CONFIRM'		=> 'Вы действительно хотите отписаться от данного форума?',
+	'UNWATCH_FORUM_DETAILED'	=> 'Вы действительно хотите отписаться от форума «%s»?',
+	'UNWATCH_TOPIC_CONFIRM'		=> 'Вы действительно хотите отписаться от данной темы?',
+	'UNWATCH_TOPIC_DETAILED'	=> 'Вы действительно хотите отписаться от темы «%s»?',
 	'UNWATCHED_FORUMS'			=> 'Вы больше не подписаны на выбранные форумы.',
 	'UNWATCHED_TOPICS'			=> 'Вы больше не подписаны на выбранные темы.',
 	'UNWATCHED_FORUMS_TOPICS'	=> 'Вы больше не подписаны на выбранное.',
@@ -699,6 +705,10 @@ $lang = array_merge($lang, array(
 
 	'WARNINGS'			=> 'Предупреждения',
 	'WARN_USER'			=> 'Вынести предупреждение',
+	'WATCH_FORUM_CONFIRM'	=> 'Вы действительно хотите подписаться на данный форум?',
+	'WATCH_FORUM_DETAILED'	=> 'Вы действительно хотите подписаться ан форум «%s»?',
+	'WATCH_TOPIC_CONFIRM'	=> 'Вы действительно хотите подписаться на данную тему?',
+	'WATCH_TOPIC_DETAILED'	=> 'Вы действительно хотите подписаться на тему «%s»?',
 	'WELCOME_SUBJECT'	=> 'Добро пожаловать на конференцию «%s»',
 	'WEBSITE'			=> 'Сайт',
 	'WHOIS'				=> 'Информация об IP-адресе',
@@ -851,28 +861,24 @@ $lang = array_merge($lang, array(
 		'0'		=> '[UTC] Время по Гринвичу: Дублин, Лондон, Лиссабон, Эдинбург',
 		'1'		=> '[UTC + 1] Берлин, Мадрид, Париж, Рим, Западная Центральная Африка',
 		'2'		=> '[UTC + 2] Афины, Вильнюс, Киев, Минск, Рига, Таллин, Центральная Африка',
-		'3'		=> '[UTC + 3] Волгоград, Москва, Самара, Санкт-Петербург',
+		'3'		=> '[UTC + 3] Багдад, Калининград, Кувейт, Эр-рияд, Найроби',
 		'3.5'	=> '[UTC + 3:30] Тегеран',
-		'4'		=> '[UTC + 4] Баку, Ереван, Тбилиси',
+		'4'		=> '[UTC + 4] Волгоград, Москва, Самара, Санкт-Петербург, Баку, Ереван, Тбилиси',
 		'4.5'	=> '[UTC + 4:30] Кабул',
-		'5'		=> '[UTC + 5] Екатеринбург, Исламабад, Карачи, Оренбург, Ташкент',
+		'5'		=> '[UTC + 5] Исламабад, Карачи,  Ташкент',
 		'5.5'	=> '[UTC + 5:30] Бомбей, Калькутта, Мадрас, Нью-Дели',
 		'5.75'	=> '[UTC + 5:45] Катманду',
-		'6'		=> '[UTC + 6] Алматы, Астана, Новосибирск, Омск',
-		'6.5'	=> '[UTC + 6:30] Рангун',
-		'7'		=> '[UTC + 7] Бангкок, Красноярск',
-		'8'		=> '[UTC + 8] Гонконг, Иркутск, Пекин, Сингапур',
-		'8.75'	=> '[UTC + 8:45] Юго-восточная Западная Австралия',
-		'9'		=> '[UTC + 9] Токио, Сеул, Чита, Якутск',
-		'9.5'	=> '[UTC + 9:30] Дарвин',
-		'10'	=> '[UTC + 10] Владивосток, Канберра, Мельбурн, Сидней',
+		'6'		=> '[UTC + 6] Алматы, Астана, Екатеринбург, Оренбург',
+		'6.5'	=> '[UTC + 6:30] Янгон',
+		'7'		=> '[UTC + 7] Бангкок, Джакарта, Новосибирск, Омск, Ханой',
+		'8'		=> '[UTC + 8] Гонконг, Красноярск, Пекин, Сингапур',
+		'9'		=> '[UTC + 9] Иркутск, Сеул, Токио',
+		'9.5'	=> '[UTC + 9:30] Аделаида, Дарвин',
+		'10'	=> '[UTC + 10] Благовещенск, Якутск',
 		'10.5'	=> '[UTC + 10:30] Лорд-Хау',
-		'11'	=> '[UTC + 11] Камчатка, Магадан, Сахалин, Соломоновы о-ва',
-		'11.5'	=> '[UTC + 11:30] Остров Норфолк',
-		'12'	=> '[UTC + 12] Новая Зеландия, Фиджи',
-		'12.75'	=> '[UTC + 12:45] Острова Чатем',
-		'13'	=> '[UTC + 13] Острова Феникс, Тонга',
-		'14'	=> '[UTC + 14] Остров Лайн',
+		'11'	=> '[UTC + 11] Владивосток, Чита, Сахалин, Хабаровск',
+		'12'	=> '[UTC + 12] Магадан, Камчатка, Фиджи',
+		'13'	=> '[UTC + 13] Нукуалофа',
 	),
 
 	// The value is only an example and will get replaced by the current time on view
